package gmodel

import (
	"context"
)

func (s *FsProductSizeModel) FindOne(ctx context.Context, id int64) (resp *FsProductSize, err error) {
	err = s.db.WithContext(ctx).Model(&FsProductSize{}).Where("`id` = ? ", id).First(&resp).Error
	return resp, err
}
func (s *FsProductSizeModel) GetAllByIds(ctx context.Context, ids []int64, sort string) (resp []FsProductSize, err error) {
	if len(ids) == 0 {
		return
	}
	db := s.db.Model(&FsProductSize{}).Where("`id` in (?) and  `status` = ?", ids, 1)
	switch sort {
	case "sort-asc":
		db = db.Order("`sort` ASC")
	case "sort-desc":
		db = db.Order("`sort` DESC")
	}
	if err = db.Find(&resp).Error; err != nil {
		return nil, err
	}
	return
}

type CountProductSizeByStatusRsp struct {
	ProductId int64 `json:"product_id"`
	Num       int64 `json:"num"`
}

func (s *FsProductSizeModel) GetGroupProductSizeByStatus(ctx context.Context, productIds []int64, status int) (resp []CountProductSizeByStatusRsp, err error) {
	err = s.db.WithContext(ctx).Model(&FsProductSize{}).
		Select("product_id,count(*) as num").
		Where("`product_id` in (?) and `status` = ?", productIds, status).
		Group("product_id").
		Find(&resp).Error
	return resp, err
}
func (s *FsProductSizeModel) GetAllByProductIds(ctx context.Context, productIds []int64, orderBy string, fields ...string) (resp []FsProductSize, err error) {
	if len(productIds) == 0 {
		return nil, nil
	}
	db := s.db.WithContext(ctx).Model(&FsProductSize{}).Where("`product_id` in(?) and  `status` = ?", productIds, 1)
	if len(fields) != 0 {
		db = db.Select(fields[0])
	}
	switch orderBy {
	case "":
		db = db.Order("`id` ASC")
	default:
		db = db.Order(orderBy)
	}
	err = db.Find(&resp).Error
	if err != nil {
		return nil, err
	}
	return
}
func (s *FsProductSizeModel) GetAllByIdsWithoutStatus(ctx context.Context, ids []int64, sort string) (resp []FsProductSize, err error) {
	if len(ids) == 0 {
		return nil, nil
	}
	db := s.db.WithContext(ctx).Model(&FsProductSize{}).Where("`id` in(?)", ids)
	switch sort {
	case "sort-asc":
		db = db.Order("`sort` ASC")
	case "sort-desc":
		db = db.Order("`sort` DESC")
	}
	err = db.Find(&resp).Error
	if err != nil {
		return nil, err
	}
	return
}

type CapacityId struct {
	Id       int64  `json:"id"`
	Capacity string `json:"capacity"`
}

func (c *FsProductSizeModel) GetAllSelectIdAndCapacityByIds(ctx context.Context, sizeIds []int64) (sizes []FsProductSize, err error) {
	err = c.db.WithContext(ctx).Where("id IN ?", sizeIds).Select("id", "capacity").Find(&sizes).Error
	return sizes, err
}
func (s *FsProductSizeModel) GetAllByStatus(ctx context.Context, status int64, sortType int, fields ...string) (resp []FsProductSize, err error) {
	db := s.db.WithContext(ctx).Model(&FsProductSize{}).Where(" `status` = ?", status)
	if len(fields) > 0 {
		db = db.Select(fields[0])
	}
	switch sortType {
	case 1:
		db = db.Order("`sort` ASC")
	case 2:
		db = db.Order("`sort` DESC")
	}
	err = db.Find(&resp).Error
	return resp, err
}
