package logic

import (
	"fmt"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"log"
	"net/http"

	"context"

	"fusenapi/server/assistant/internal/svc"
	"fusenapi/server/assistant/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type RedirectLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext

	RedirectUrl string
}

func NewRedirectLogic(ctx context.Context, svcCtx *svc.ServiceContext) *RedirectLogic {
	return &RedirectLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *RedirectLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

// 处理逻辑后 w,r 如:重定向
func (l *RedirectLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
	if l.RedirectUrl != "" {
		html := fmt.Sprintf(`
	<!DOCTYPE html>
	<html>
	<head>
		<title>Redirect</title>
		<script type="text/javascript">
			window.onload = function() {
				window.location = %s;
			}
		</script>
	</head>
	<body>
	</body>
	</html>
	`, l.RedirectUrl)
		fmt.Fprintln(w, html)
	}

}

func (l *RedirectLogic) Redirect(req *types.RequestRedirect, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	l.RedirectUrl = req.Url
	log.Println(req.Url)
	return resp.SetStatus(basic.CodeOK)
}
