package handler

import (
	"errors"
	"fmt"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/utils/basic"

	"fusenapi/server/backend/internal/logic"
	"fusenapi/server/backend/internal/svc"
	"fusenapi/server/backend/internal/types"
)

func BackendUserLoginHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {

		var req types.RequestUserLogin

		// 创建一个业务逻辑层实例
		l := logic.NewBackendUserLoginLogic(r.Context(), svcCtx)
		resp, token := l.BackendUserLogin(&req)
		if resp.Code == basic.CodeOK.Code {
			w.Header().Add("Authorization", fmt.Sprintf("Bearer %s", token))
		}

		// 如果响应不为nil，则使用httpx.OkJsonCtx方法返回JSON响应;
		// 否则，发送500内部服务器错误的JSON响应并记录错误消息logx.Error。
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
