package logic

import (
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/home-user-auth/internal/svc"
	"fusenapi/server/home-user-auth/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type UserAddAddressLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewUserAddAddressLogic(ctx context.Context, svcCtx *svc.ServiceContext) *UserAddAddressLogic {
	return &UserAddAddressLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *UserAddAddressLogic) UserAddAddress(req *types.RequestAddAddress, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	if !userinfo.IsUser() {
		return resp.SetStatus(basic.CodeUnAuth) // 如果不是用户信息, 返回未授权错误
	}

	// 确认这个IsDefault的值范围
	if !auth.CheckValueRange(req.IsDefault, 0, 1) {
		return resp.SetStatus(basic.CodeSafeValueRangeErr) // IsDefault值超出范围, 返回安全值范围错误
	}

	m := l.svcCtx.AllModels.FsAddress // 创建地址模型
	var status int64 = 1              // 默认地址状态为1(正常)

	// 如果ID为0, 表示新增地址
	if req.Id == 0 {
		var (
			country   string = "USA" // 国家默认为美国
			isDefautl int64  = 1     // 默认地址为1
		)
		createOne := &gmodel.FsAddress{ // 构建FsAddress结构体
			Name:      &req.Name,
			FirstName: &req.FirstName,
			LastName:  &req.LastName,
			Mobile:    &req.Mobile,
			Street:    &req.Street,
			Suite:     &req.Suite,
			City:      &req.City,
			State:     &req.State,
			Country:   &country,
			Status:    &status,
			UserId:    &userinfo.UserId,
			ZipCode:   &req.ZipCode,
			IsDefault: &isDefautl,
		}
		created, err := m.CreateOne(l.ctx, createOne) // 新增地址
		if err != nil {
			logx.Error(err)                              // 日志记录错误
			return resp.SetStatus(basic.CodeDbCreateErr) // 返回数据库创建错误
		}
		return resp.SetStatus(basic.CodeOK, map[string]int64{"id": created.Id}) // 返回成功并返回地址ID
	}

	address := &gmodel.FsAddress{
		Id:        req.Id,
		Name:      &req.Name,
		FirstName: &req.FirstName,
		LastName:  &req.LastName,
		Mobile:    &req.Mobile,
		Street:    &req.Street,
		Suite:     &req.Suite,
		City:      &req.City,
		State:     &req.State,
		Status:    &status,
		UserId:    &userinfo.UserId,
		ZipCode:   &req.ZipCode,
		IsDefault: &req.IsDefault,
	}

	// 插入数据库 更新地址
	err := m.UpdateAddAddress(l.ctx, address)
	if err != nil {
		logx.Error(err)
		return resp.SetStatus(basic.CodeDbUpdateErr)
	}

	return resp.SetStatus(basic.CodeOK, map[string]int64{"id": address.Id})
}
