package logic

import (
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/product-template-tag/internal/svc"
	"fusenapi/server/product-template-tag/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetProductTemplateTagsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetProductTemplateTagsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetProductTemplateTagsLogic {
	return &GetProductTemplateTagsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *GetProductTemplateTagsLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *GetProductTemplateTagsLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }

func (l *GetProductTemplateTagsLogic) GetProductTemplateTags(req *types.GetProductTemplateTagsReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	if req.Limit <= 0 || req.Limit > 100 {
		req.Limit = 4
	}
	productTemplateTags, err := l.svcCtx.AllModels.FsProductTemplateTags.GetList(l.ctx, 1, req.Limit, "`id` DESC")
	if err != nil {
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeDbSqlErr, "failed to get template tags")
	}
	list := make([]types.GetProductTemplateTagsRsp, 0, len(productTemplateTags))
	for _, v := range productTemplateTags {
		list = append(list, types.GetProductTemplateTagsRsp{
			Id:    v.Id,
			Tag:   *v.Title,
			Cover: *v.CoverImg,
		})
	}
	return resp.SetStatusWithMessage(basic.CodeOK, "success", list)
}
