package main

import (
	"flag"
	"fmt"
	"net/http"
	"time"

	"fusenapi/server/shopping-cart-confirmation/internal/config"
	"fusenapi/server/shopping-cart-confirmation/internal/handler"
	"fusenapi/server/shopping-cart-confirmation/internal/svc"
	"fusenapi/utils/auth"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/rest"
)

var configFile = flag.String("f", "etc/shopping-cart-confirmation.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	c.Timeout = int64(time.Second * 15)

	server := rest.MustNewServer(c.RestConf, rest.WithCustomCors(auth.FsCors, func(w http.ResponseWriter) {

	}))
	defer server.Stop()

	ctx := svc.NewServiceContext(c)
	handler.RegisterHandlers(server, ctx)

	fmt.Printf("Starting server at %s:%d...\n", c.Host, c.Port)
	server.Start()
}

// var testConfigFile = flag.String("f", "../etc/shopping-cart-confirmation.yaml", "the config file")
// var cnf config.Config

// func GetTestServer() *rest.Server {
// 	flag.Parse()

// 	conf.MustLoad(*testConfigFile, &cnf)

// 	server := rest.MustNewServer(cnf.RestConf)
// 	defer server.Stop()

// 	ctx := svc.NewServiceContext(cnf)
// 	handler.RegisterHandlers(server, ctx)

// 	fmt.Printf("Starting server at %s:%d...\n", cnf.Host, cnf.Port)
// 	return server
// }
